@@ -40,10 +40,13 @@ pub fn plugin_registrar(reg: &mut Registry) {
     reg.register_syntax_extension(intern("cpp_header"),
                                   SyntaxExtension::NormalTT(Box::new(mac::expand_cpp_header),
                                                             None, false));
+    reg.register_syntax_extension(intern("cpp_flags"),
+                                  SyntaxExtension::NormalTT(Box::new(mac::expand_cpp_flags),
+                                                            None, false));
     reg.register_syntax_extension(intern("cpp"),
                                   SyntaxExtension::NormalTT(Box::new(mac::expand_cpp),
                                                             None, false));
 
-    reg.register_lint_pass(Box::new(lint::CppLintPass));
+    reg.register_late_lint_pass(Box::new(lint::CppLintPass));
     reg.register_attribute(format!("cpp_type"), AttributeType::Whitelisted);
 }
