@@ -51,8 +51,10 @@ impl LintPass for CppLintPass {
     fn get_lints(&self) -> LintArray {
         lint_array!(types::BAD_CXX_TYPE)
     }
+}
 
-    fn check_expr(&mut self, cx: &Context, exp: &Expr) {
+impl LateLintPass for CppLintPass {
+    fn check_expr(&mut self, cx: &LateContext, exp: &Expr) {
         if let ExprCall(ref callee, ref args) = exp.node {
             if let ExprPath(None, ref path) = callee.node {
                 if path.segments.len() == 1 {
@@ -65,7 +67,7 @@ impl LintPass for CppLintPass {
     }
 }
 
-fn record_type_data(cx: &Context, name: &str, call: &Expr, args: &[P<Expr>]) {
+fn record_type_data(cx: &LateContext, name: &str, call: &Expr, args: &[P<Expr>]) {
     let mut headers = CPP_HEADERS.lock().unwrap();
     let mut decls = CPP_FNDECLS.lock().unwrap();
     let mut types = CPP_TYPEDATA.lock().unwrap();
@@ -104,7 +106,7 @@ fn record_type_data(cx: &Context, name: &str, call: &Expr, args: &[P<Expr>]) {
     }
 }
 
-fn finalize(cx: &Context,
+fn finalize(cx: &LateContext,
             headers: &mut String,
             types: &mut types::TypeData,
             decls: &mut HashMap<String, CppFn>) {
@@ -185,11 +187,12 @@ extern "C" {{{}}}
     let out_dir = super_hack_get_out_dir();
 
     // Create the C++ file which we will compile
-    {
+    let cpp_filename = {
         let path = path::Path::new(&out_dir).join("rust_cpp_tmp.cpp");
-        let mut f = File::create(path).unwrap();
+        let mut f = File::create(&path).unwrap();
         f.write_all(cppcode.as_bytes()).unwrap();
-    }
+        path
+    };
 
 
     // Unfortunately, once the compiler is running, which it is (as we are running
@@ -218,10 +221,17 @@ extern "C" {{{}}}
     env::set_var("CXXFLAGS", format!("{} {}", env::var("CXXFLAGS").unwrap_or(String::new()),
                                      "-std=c++0x"));
 
+    let flags = CPP_FLAGS.lock().unwrap();
+    let mut config = gcc::Config::new();
+
+    for flag in &*flags {
+        config.flag(flag);
+    }
+
     println!("########### Running GCC ###########");
-    gcc::Config::new()
+    config
         .cpp(true)
-        .file("rust_cpp_tmp.cpp")
+        .file(cpp_filename)
         .compile("librust_cpp_tmp.a");
     println!("########### Done Rust-C++ ############");
 }
