@@ -1,6 +1,6 @@
 use data::*;
 
-use syntax::parse::token::intern;
+use syntax::parse::token::{intern, Eof};
 use syntax::codemap::Span;
 use syntax::util::small_vector::SmallVector;
 use syntax::abi;
@@ -59,6 +59,24 @@ pub fn expand_cpp_header<'a>(ec: &'a mut ExtCtxt,
     MacEager::items(SmallVector::zero())
 }
 
+pub fn expand_cpp_flags<'a>(ec: &'a mut ExtCtxt,
+                            mac_span: Span,
+                            tts: &[TokenTree]) -> Box<MacResult + 'a> {
+    let mut parser = ec.new_parser_from_tts(tts);
+    let mut flags = CPP_FLAGS.lock().unwrap();
+
+    while let Some(Some((ref s, _, _))) = parser.parse_optional_str().ok() {
+        flags.push(s.to_string());
+    }
+
+    if let Err(_) = parser.expect(&Eof) {
+        ec.span_err(mac_span, "cpp_flags! may only contain string literals");
+        return DummyResult::expr(mac_span);
+    }
+
+    MacEager::items(SmallVector::zero())
+}
+
 pub fn expand_cpp<'a>(ec: &'a mut ExtCtxt,
                       mac_span: Span,
                       tts: &[TokenTree]) -> Box<MacResult + 'a> {
@@ -129,7 +147,7 @@ pub fn expand_cpp<'a>(ec: &'a mut ExtCtxt,
     let params: Vec<_> = captured_idents.iter().map(|&(ref id, mutable)| {
         let arg_ty = ec.ty_ptr(mac_span,
                                ec.ty_ident(mac_span,
-                                           Ident::new(intern("u8"))),
+                                           Ident::with_empty_ctxt(intern("u8"))),
                                mutable);
         ec.arg(mac_span, id.clone(), arg_ty)
     }).collect();
@@ -137,7 +155,7 @@ pub fn expand_cpp<'a>(ec: &'a mut ExtCtxt,
     let args: Vec<_> = captured_idents.iter().map(|&(ref id, mutable)| {
         let arg_ty = ec.ty_ptr(mac_span,
                                ec.ty_ident(mac_span,
-                                           Ident::new(intern("u8"))),
+                                           Ident::with_empty_ctxt(intern("u8"))),
                                mutable);
 
         let addr_of = if mutable == MutImmutable {
@@ -155,7 +173,7 @@ pub fn expand_cpp<'a>(ec: &'a mut ExtCtxt,
                      arg_ty)
     }).collect();
 
-    let fn_ident = Ident::new(intern(
+    let fn_ident = Ident::with_empty_ctxt(intern(
         &format!("rust_cpp_{}", Uuid::new_v4().to_simple_string())));
 
     // extern "C" declaration of function
